plottool_ibeis
==============

|ReadTheDocs| |Pypi| |Downloads| |Codecov| |CircleCI| |Travis| |Appveyor| 

Helpers for matplotlib computer vision plots for the IBEIS / WildMe project

.. |CircleCI| image:: https://circleci.com/gh/Erotemic/plottool.svg?style=svg
    :target: https://circleci.com/gh/Erotemic/plottool
.. |Travis| image:: https://img.shields.io/travis/Erotemic/plottool/master.svg?label=Travis%20CI
   :target: https://travis-ci.org/Erotemic/plottool?branch=master
.. |Appveyor| image:: https://ci.appveyor.com/api/projects/status/github/Erotemic/plottool?branch=master&svg=True
   :target: https://ci.appveyor.com/project/Erotemic/plottool/branch/master
.. |Codecov| image:: https://codecov.io/github/Erotemic/plottool/badge.svg?branch=master&service=github
   :target: https://codecov.io/github/Erotemic/plottool?branch=master
.. |Pypi| image:: https://img.shields.io/pypi/v/plottool_ibeis.svg
   :target: https://pypi.python.org/pypi/plottool_ibeis
.. |Downloads| image:: https://img.shields.io/pypi/dm/plottool_ibeis.svg
   :target: https://pypistats.org/packages/plottool_ibeis
.. |ReadTheDocs| image:: https://readthedocs.org/projects/plottool_ibeis/badge/?version=latest
    :target: http://plottool_ibeis.readthedocs.io/en/latest/
